@@ -36,15 +36,15 @@
 #include <QtCore/QFile>
 #include <QtCore/QStringList>
 #include <QtDBus/QtDBus>
+#include <QKeyEvent>
 
 // KDE
-#include <KDebug>
+#include <QDebug>
 #include <KLocalizedString>
 #include <KNotification>
 #include <KRun>
 #include <KShell>
 #include <KProcess>
-#include <KStandardDirs>
 #include <KConfigGroup>
 
 // Konsole
@@ -126,24 +126,15 @@ Session::Session(QObject* parent) :
     //create emulation backend
     _emulation = new Vt102Emulation();
 
-    connect(_emulation, SIGNAL(titleChanged(int,QString)),
-            this, SLOT(setUserTitle(int,QString)));
-    connect(_emulation, SIGNAL(stateSet(int)),
-            this, SLOT(activityStateSet(int)));
-    connect(_emulation, SIGNAL(zmodemDetected()),
-            this, SLOT(fireZModemDetected()));
-    connect(_emulation, SIGNAL(changeTabTextColorRequest(int)),
-            this, SIGNAL(changeTabTextColorRequest(int)));
-    connect(_emulation, SIGNAL(profileChangeCommandReceived(QString)),
-            this, SIGNAL(profileChangeCommandReceived(QString)));
-    connect(_emulation, SIGNAL(flowControlKeyPressed(bool)),
-            this, SLOT(updateFlowControlState(bool)));
-    connect(_emulation, SIGNAL(primaryScreenInUse(bool)),
-            this, SLOT(onPrimaryScreenInUse(bool)));
-    connect(_emulation, SIGNAL(selectionChanged(QString)),
-            this, SIGNAL(selectionChanged(QString)));
-    connect(_emulation, SIGNAL(imageResizeRequest(QSize)),
-            this, SIGNAL(resizeRequest(QSize)));
+    connect(_emulation, &Konsole::Emulation::titleChanged, this, &Konsole::Session::setUserTitle);
+    connect(_emulation, &Konsole::Emulation::stateSet, this, &Konsole::Session::activityStateSet);
+    connect(_emulation, &Konsole::Emulation::zmodemDetected, this, &Konsole::Session::fireZModemDetected);
+    connect(_emulation, &Konsole::Emulation::changeTabTextColorRequest, this, &Konsole::Session::changeTabTextColorRequest);
+    connect(_emulation, &Konsole::Emulation::profileChangeCommandReceived, this, &Konsole::Session::profileChangeCommandReceived);
+    connect(_emulation, &Konsole::Emulation::flowControlKeyPressed, this, &Konsole::Session::updateFlowControlState);
+    connect(_emulation, &Konsole::Emulation::primaryScreenInUse, this, &Konsole::Session::onPrimaryScreenInUse);
+    connect(_emulation, &Konsole::Emulation::selectionChanged, this, &Konsole::Session::selectionChanged);
+    connect(_emulation, &Konsole::Emulation::imageResizeRequest, this, &Konsole::Session::resizeRequest);
 
     //create new teletype for I/O with shell process
     openTeletype(-1);
@@ -151,11 +142,11 @@ Session::Session(QObject* parent) :
     //setup timer for monitoring session activity & silence
     _silenceTimer = new QTimer(this);
     _silenceTimer->setSingleShot(true);
-    connect(_silenceTimer, SIGNAL(timeout()), this, SLOT(silenceTimerDone()));
+    connect(_silenceTimer, &QTimer::timeout, this, &Konsole::Session::silenceTimerDone);
 
     _activityTimer = new QTimer(this);
     _activityTimer->setSingleShot(true);
-    connect(_activityTimer, SIGNAL(timeout()), this, SLOT(activityTimerDone()));
+    connect(_activityTimer, &QTimer::timeout, this, &Konsole::Session::activityTimerDone);
 }
 
 Session::~Session()
@@ -170,7 +161,7 @@ Session::~Session()
 void Session::openTeletype(int fd)
 {
     if (isRunning()) {
-        kWarning() << "Attempted to open teletype in a running session.";
+        qWarning() << "Attempted to open teletype in a running session.";
         return;
     }
 
@@ -184,24 +175,18 @@ void Session::openTeletype(int fd)
     _shellProcess->setUtf8Mode(_emulation->utf8());
 
     // connect the I/O between emulator and pty process
-    connect(_shellProcess, SIGNAL(receivedData(const char*,int)),
-            this, SLOT(onReceiveBlock(const char*,int)));
-    connect(_emulation, SIGNAL(sendData(const char*,int)),
-            _shellProcess, SLOT(sendData(const char*,int)));
+    connect(_shellProcess, &Konsole::Pty::receivedData, this, &Konsole::Session::onReceiveBlock);
+    connect(_emulation, &Konsole::Emulation::sendData, _shellProcess, &Konsole::Pty::sendData);
 
     // UTF8 mode
-    connect(_emulation, SIGNAL(useUtf8Request(bool)),
-            _shellProcess, SLOT(setUtf8Mode(bool)));
+    connect(_emulation, &Konsole::Emulation::useUtf8Request, _shellProcess, &Konsole::Pty::setUtf8Mode);
 
     // get notified when the pty process is finished
-    connect(_shellProcess, SIGNAL(finished(int,QProcess::ExitStatus)),
-            this, SLOT(done(int,QProcess::ExitStatus)));
+    connect(_shellProcess, static_cast<void(Pty::*)(int,QProcess::ExitStatus)>(&Konsole::Pty::finished), this, &Konsole::Session::done);
 
     // emulator size
-    connect(_emulation, SIGNAL(imageSizeChanged(int,int)),
-            this, SLOT(updateWindowSize(int,int)));
-    connect(_emulation, SIGNAL(imageSizeInitialized()),
-            this, SLOT(run()));
+    connect(_emulation, &Konsole::Emulation::imageSizeChanged, this, &Konsole::Session::updateWindowSize);
+    connect(_emulation, &Konsole::Emulation::imageSizeInitialized, this, &Konsole::Session::run);
 }
 
 WId Session::windowId() const
@@ -287,17 +272,15 @@ QString Session::currentWorkingDirectory()
 
     return _currentWorkingDir;
 }
-ProcessInfo* Session::updateWorkingDirectory()
+void Session::updateWorkingDirectory()
 {
-    ProcessInfo* process = getProcessInfo();
+    updateSessionProcessInfo();
 
-    const QString currentDir = process->validCurrentDir();
+    const QString currentDir = _sessionProcessInfo->validCurrentDir();
     if (currentDir != _currentWorkingDir) {
         _currentWorkingDir = currentDir;
         emit currentDirectoryChanged(_currentWorkingDir);
     }
-
-    return process;
 }
 
 QList<TerminalDisplay*> Session::views() const
@@ -312,33 +295,26 @@ void Session::addView(TerminalDisplay* widget)
     _views.append(widget);
 
     // connect emulation - view signals and slots
-    connect(widget, SIGNAL(keyPressedSignal(QKeyEvent*)),
-            _emulation, SLOT(sendKeyEvent(QKeyEvent*)));
-    connect(widget, SIGNAL(mouseSignal(int,int,int,int)),
-            _emulation, SLOT(sendMouseEvent(int,int,int,int)));
-    connect(widget, SIGNAL(sendStringToEmu(const char*)),
-            _emulation, SLOT(sendString(const char*)));
+    connect(widget, &Konsole::TerminalDisplay::keyPressedSignal, _emulation, &Konsole::Emulation::sendKeyEvent);
+    connect(widget, &Konsole::TerminalDisplay::mouseSignal, _emulation, &Konsole::Emulation::sendMouseEvent);
+    connect(widget, &Konsole::TerminalDisplay::sendStringToEmu, _emulation, &Konsole::Emulation::sendString);
 
     // allow emulation to notify view when the foreground process
     // indicates whether or not it is interested in mouse signals
-    connect(_emulation, SIGNAL(programUsesMouseChanged(bool)),
-            widget, SLOT(setUsesMouse(bool)));
+    connect(_emulation, &Konsole::Emulation::programUsesMouseChanged, widget, &Konsole::TerminalDisplay::setUsesMouse);
 
     widget->setUsesMouse(_emulation->programUsesMouse());
 
-    connect(_emulation, SIGNAL(programBracketedPasteModeChanged(bool)),
-            widget, SLOT(setBracketedPasteMode(bool)));
+    connect(_emulation, &Konsole::Emulation::programBracketedPasteModeChanged, widget, &Konsole::TerminalDisplay::setBracketedPasteMode);
 
     widget->setBracketedPasteMode(_emulation->programBracketedPasteMode());
 
     widget->setScreenWindow(_emulation->createWindow());
 
     //connect view signals and slots
-    connect(widget, SIGNAL(changedContentSizeSignal(int,int)),
-            this, SLOT(onViewSizeChange(int,int)));
+    connect(widget, &Konsole::TerminalDisplay::changedContentSizeSignal, this, &Konsole::Session::onViewSizeChange);
 
-    connect(widget, SIGNAL(destroyed(QObject*)),
-            this, SLOT(viewDestroyed(QObject*)));
+    connect(widget, &Konsole::TerminalDisplay::destroyed, this, &Konsole::Session::viewDestroyed);
 }
 
 void Session::viewDestroyed(QObject* view)
@@ -391,9 +367,9 @@ QString Session::checkProgram(const QString& program)
 
     exec = KRun::binaryName(exec, false);
     exec = KShell::tildeExpand(exec);
-    QString pexec = KStandardDirs::findExe(exec);
+    const QString pexec = QStandardPaths::findExecutable(exec);
     if (pexec.isEmpty()) {
-        kError() << i18n("Could not find binary: ") << exec;
+        qCritical() << i18n("Could not find binary: ") << exec;
         return QString();
     }
 
@@ -428,16 +404,16 @@ void Session::run()
 {
     // extra safeguard for potential bug.
     if (isRunning()) {
-        kWarning() << "Attempted to re-run an already running session.";
+        qWarning() << "Attempted to re-run an already running session.";
         return;
     }
 
     //check that everything is in place to run the session
     if (_program.isEmpty()) {
-        kWarning() << "Program to run not set.";
+        qWarning() << "Program to run not set.";
     }
     if (_arguments.isEmpty()) {
-        kWarning() << "No command line arguments specified.";
+        qWarning() << "No command line arguments specified.";
     }
     if (_uniqueIdentifier.isNull()) {
         _uniqueIdentifier = createUuid();
@@ -446,12 +422,7 @@ void Session::run()
     const int CHOICE_COUNT = 3;
     // if '_program' is empty , fall back to default shell. If that is not set
     // then fall back to /bin/sh
-#ifndef _WIN32
     QString programs[CHOICE_COUNT] = {_program, qgetenv("SHELL"), "/bin/sh"};
-#else
-    // on windows, fall back to %COMSPEC% or to cmd.exe
-    QString programs[CHOICE_COUNT] = {_program, qgetenv("COMSPEC"), "cmd.exe"};
-#endif
     QString exec;
     int choice = 0;
     while (choice < CHOICE_COUNT) {
@@ -797,7 +768,7 @@ bool Session::closeInNormalWay()
     if (kill(SIGHUP)) {
         return true;
     } else {
-        kWarning() << "Process " << _shellProcess->pid() << " did not die with SIGHUP";
+        qWarning() << "Process " << _shellProcess->pid() << " did not die with SIGHUP";
         _shellProcess->closePty();
         return (_shellProcess->waitForFinished(1000));
     }
@@ -811,7 +782,7 @@ bool Session::closeInForceWay()
     if (kill(SIGKILL)) {
         return true;
     } else {
-        kWarning() << "Process " << _shellProcess->pid() << " did not die with SIGKILL";
+        qWarning() << "Process " << _shellProcess->pid() << " did not die with SIGKILL";
         return false;
     }
 }
@@ -834,8 +805,8 @@ void Session::sendMouseEvent(int buttons, int column, int line, int eventType)
 void Session::done(int exitCode, QProcess::ExitStatus exitStatus)
 {
     // This slot should be triggered only one time
-    disconnect(_shellProcess, SIGNAL(finished(int,QProcess::ExitStatus)),
-               this, SLOT(done(int,QProcess::ExitStatus)));
+    disconnect(_shellProcess, static_cast<void(Pty::*)(int,QProcess::ExitStatus)>(&Konsole::Pty::finished),
+               this, &Konsole::Session::done);
 
     if (!_autoClose) {
         _userTitle = i18nc("@info:shell This session is done", "Finished");
@@ -989,7 +960,8 @@ bool Session::isRemote()
 QString Session::getDynamicTitle()
 {
     // update current directory from process
-    ProcessInfo* process = updateWorkingDirectory();
+    updateWorkingDirectory();
+    ProcessInfo* process = getProcessInfo();
 
     // format tab titles using process info
     bool ok = false;
@@ -1004,7 +976,7 @@ QString Session::getDynamicTitle()
     return title;
 }
 
-KUrl Session::getUrl()
+QUrl Session::getUrl()
 {
     QString path;
 
@@ -1037,7 +1009,7 @@ KUrl Session::getUrl()
         }
     }
 
-    return KUrl(path);
+    return QUrl(path);
 }
 
 void Session::setIconName(const QString& iconName)
@@ -1175,7 +1147,7 @@ void Session::fireZModemDetected()
 
 void Session::cancelZModem()
 {
-    _shellProcess->sendData("\030\030\030\030", 4); // Abort
+    _shellProcess->sendData(QByteArrayLiteral("\030\030\030\030")); // Abort
     _zmodemBusy = false;
 }
 
@@ -1190,25 +1162,20 @@ void Session::startZModem(const QString& zmodem, const QString& dir, const QStri
     if (!dir.isEmpty())
         _zmodemProc->setWorkingDirectory(dir);
 
-    connect(_zmodemProc, SIGNAL(readyReadStandardOutput()),
-            this, SLOT(zmodemReadAndSendBlock()));
-    connect(_zmodemProc, SIGNAL(readyReadStandardError()),
-            this, SLOT(zmodemReadStatus()));
-    connect(_zmodemProc, SIGNAL(finished(int,QProcess::ExitStatus)),
-            this, SLOT(zmodemFinished()));
+    connect(_zmodemProc, &KProcess::readyReadStandardOutput, this, &Konsole::Session::zmodemReadAndSendBlock);
+    connect(_zmodemProc, &KProcess::readyReadStandardError, this, &Konsole::Session::zmodemReadStatus);
+    connect(_zmodemProc, static_cast<void(KProcess::*)(int,QProcess::ExitStatus)>(&KProcess::finished), this, &Konsole::Session::zmodemFinished);
 
     _zmodemProc->start();
 
-    disconnect(_shellProcess, SIGNAL(receivedData(const char*,int)),
-               this, SLOT(onReceiveBlock(const char*,int)));
-    connect(_shellProcess, SIGNAL(receivedData(const char*,int)),
-            this, SLOT(zmodemReceiveBlock(const char*,int)));
+    disconnect(_shellProcess, &Konsole::Pty::receivedData,
+               this, &Konsole::Session::onReceiveBlock);
+    connect(_shellProcess, &Konsole::Pty::receivedData, this, &Konsole::Session::zmodemReceiveBlock);
 
     _zmodemProgress = new ZModemDialog(QApplication::activeWindow(), false,
                                        i18n("ZModem Progress"));
 
-    connect(_zmodemProgress, SIGNAL(user1Clicked()),
-            this, SLOT(zmodemFinished()));
+    connect(_zmodemProgress, &Konsole::ZModemDialog::user1Clicked, this, &Konsole::Session::zmodemFinished);
 
     _zmodemProgress->show();
 }
@@ -1221,7 +1188,7 @@ void Session::zmodemReadAndSendBlock()
     if (data.count() == 0)
         return;
 
-    _shellProcess->sendData(data.constData(), data.count());
+    _shellProcess->sendData(data);
 }
 
 void Session::zmodemReadStatus()
@@ -1265,13 +1232,12 @@ void Session::zmodemFinished()
         _zmodemBusy = false;
         delete process;    // Now, the KProcess may be disposed safely.
 
-        disconnect(_shellProcess, SIGNAL(receivedData(const char*,int)),
-                   this , SLOT(zmodemReceiveBlock(const char*,int)));
-        connect(_shellProcess, SIGNAL(receivedData(const char*,int)),
-                this, SLOT(onReceiveBlock(const char*,int)));
+        disconnect(_shellProcess, &Konsole::Pty::receivedData,
+                   this , &Konsole::Session::zmodemReceiveBlock);
+        connect(_shellProcess, &Konsole::Pty::receivedData, this, &Konsole::Session::onReceiveBlock);
 
-        _shellProcess->sendData("\030\030\030\030", 4); // Abort
-        _shellProcess->sendData("\001\013\n", 3); // Try to get prompt back
+        _shellProcess->sendData(QByteArrayLiteral("\030\030\030\030")); // Abort
+        _shellProcess->sendData(QByteArrayLiteral("\001\013\n")); // Try to get prompt back
         _zmodemProgress->transferDone();
     }
 }
@@ -1468,12 +1434,12 @@ bool SessionGroup::masterStatus(Session* session) const
 
 void SessionGroup::addSession(Session* session)
 {
-    connect(session, SIGNAL(finished()), this, SLOT(sessionFinished()));
+    connect(session, &Konsole::Session::finished, this, &Konsole::SessionGroup::sessionFinished);
     _sessions.insert(session, false);
 }
 void SessionGroup::removeSession(Session* session)
 {
-    disconnect(session, SIGNAL(finished()), this, SLOT(sessionFinished()));
+    disconnect(session, &Konsole::Session::finished, this, &Konsole::SessionGroup::sessionFinished);
     setMasterStatus(session, false);
     _sessions.remove(session);
 }
@@ -1502,14 +1468,13 @@ void SessionGroup::setMasterStatus(Session* session , bool master)
     _sessions[session] = master;
 
     if (master) {
-        connect(session->emulation(), SIGNAL(sendData(const char*,int)),
-                this, SLOT(forwardData(const char*,int)));
+        connect(session->emulation(), &Konsole::Emulation::sendData, this, &Konsole::SessionGroup::forwardData);
     } else {
-        disconnect(session->emulation(), SIGNAL(sendData(const char*,int)),
-                   this, SLOT(forwardData(const char*,int)));
+        disconnect(session->emulation(), &Konsole::Emulation::sendData,
+                   this, &Konsole::SessionGroup::forwardData);
     }
 }
-void SessionGroup::forwardData(const char* data, int size)
+void SessionGroup::forwardData(const QByteArray& data)
 {
     static bool _inForwardData = false;
     if (_inForwardData) {  // Avoid recursive calls among session groups!
@@ -1523,11 +1488,9 @@ void SessionGroup::forwardData(const char* data, int size)
     _inForwardData = true;
     foreach(Session* other, _sessions.keys()) {
         if (!_sessions[other]) {
-            other->emulation()->sendString(data, size);
+            other->emulation()->sendString(data);
         }
     }
     _inForwardData = false;
 }
 
-#include "Session.moc"
-
