@@ -32,12 +32,10 @@
 #include <QtCore/QSize>
 #include <QtCore/QProcess>
 #include <QWidget>
-
-// KDE
-#include <KUrl>
+#include <QtCore/QUrl>
 
 // Konsole
-#include "konsole_export.h"
+#include "konsoleprivate_export.h"
 
 class QColor;
 
@@ -53,6 +51,17 @@ class TerminalDisplay;
 class ZModemDialog;
 class HistoryType;
 
+/**
+ * Platform-specific main shortcut "opcode":
+ */
+enum Modifier {
+#ifdef Q_OS_MAC
+    ACCEL = Qt::META
+#else
+    ACCEL = Qt::CTRL
+#endif
+};
+
 /**
  * Represents a terminal session consisting of a pseudo-teletype and a terminal emulation.
  * The pseudo-teletype (or PTY) handles I/O between the terminal process and Konsole.
@@ -263,7 +272,7 @@ public:
     QString iconName() const;
 
     /** Return URL for the session. */
-    KUrl getUrl();
+    QUrl getUrl();
 
     /** Sets the text of the icon associated with this session. */
     void setIconText(const QString& iconText);
@@ -693,7 +702,7 @@ private:
     ProcessInfo* getProcessInfo();
     void updateSessionProcessInfo();
     bool updateForegroundProcessInfo();
-    ProcessInfo* updateWorkingDirectory();
+    void updateWorkingDirectory();
 
     QUuid            _uniqueIdentifier; // SHELL_SESSION_ID
 
@@ -813,7 +822,7 @@ public:
 
 private slots:
     void sessionFinished();
-    void forwardData(const char* data, int size);
+    void forwardData(const QByteArray& data);
 
 private:
     QList<Session*> masters() const;
